@@ -33,7 +33,7 @@
 #![warn(missing_docs)]
 #![no_std]
 #![cfg_attr(
-    feature = "nightly", feature(const_fn, cfg_target_has_atomic, integer_atomics, atomic_min_max)
+    feature = "nightly", feature(const_fn, const_int_ops, const_let, cfg_target_has_atomic, integer_atomics, atomic_min_max)
 )]
 
 #[cfg(test)]
@@ -98,6 +98,18 @@ impl<T: Copy> Atomic<T> {
     /// internally, which makes it unsuitable for some situations (such as
     /// communicating with a signal handler).
     #[inline]
+    #[cfg(feature = "nightly")]
+    pub const fn is_lock_free() -> bool {
+        ops::atomic_is_lock_free::<T>()
+    }
+
+    /// Checks if `Atomic` objects of this type are lock-free.
+    ///
+    /// If an `Atomic` is not lock-free then it may be implemented using locks
+    /// internally, which makes it unsuitable for some situations (such as
+    /// communicating with a signal handler).
+    #[inline]
+    #[cfg(not(feature = "nightly"))]
     pub fn is_lock_free() -> bool {
         ops::atomic_is_lock_free::<T>()
     }
